==> beamlit-0.0.56rc104.tar.gz: beamlit-0.0.56rc104/docs/beamlit/api/functions/delete_function.md <==
Module beamlit.api.functions.delete_function
============================================

Functions
---------

`asyncio(function_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.models.function.Function | None`
:   Delete function by name
    
    Args:
        function_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Function

`asyncio_detailed(function_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.types.Response[beamlit.models.function.Function]`
:   Delete function by name
    
    Args:
        function_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Function]

`sync(function_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.models.function.Function | None`
:   Delete function by name
    
    Args:
        function_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Function

`sync_detailed(function_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.types.Response[beamlit.models.function.Function]`
:   Delete function by name
    
    Args:
        function_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Function]

==> beamlit-0.0.62.tar.gz: beamlit-0.0.62/docs/beamlit/api/functions/delete_function.md <==
Module beamlit.api.functions.delete_function
============================================

Functions
---------

`asyncio(function_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.models.function.Function | None`
:   Delete function by name
    
    Args:
        function_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Function

`asyncio_detailed(function_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.types.Response[beamlit.models.function.Function]`
:   Delete function by name
    
    Args:
        function_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Function]

`sync(function_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.models.function.Function | None`
:   Delete function by name
    
    Args:
        function_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Function

`sync_detailed(function_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.types.Response[beamlit.models.function.Function]`
:   Delete function by name
    
    Args:
        function_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Function]
